@@ -51,11 +51,10 @@ class SourcePackage:
         else:
             shutil.copytree(fetch_result.storage_path, self.fetch_directory)
 
-    @classmethod
-    def _install_here_document(cls, entry: HereDocument, destination: Path) -> None:
+    def _install_here_document(self, entry: HereDocument, destination: Path) -> None:
         if destination.exists():
             raise Ops2debGeneratorError(f"Destination {destination} already exists")
-        destination.write_text(entry.content)
+        destination.write_text(self.blueprint.render_string(entry.content))
 
     def _install_source_destination_str(
         self, entry: SourceDestinationStr, destination: Path
@@ -162,6 +161,7 @@ def generate(
     blueprints: List[Blueprint],
     output_directory: Path,
     debian_repository: Optional[str] = None,
+    only_names: Optional[List[str]] = None,
 ) -> List[SourcePackage]:
     # each blueprint can yield multiple source packages, one per supported arch
     packages = [SourcePackage(b, output_directory) for b in extend(blueprints)]
@@ -170,6 +170,9 @@ def generate(
     if debian_repository is not None:
         packages = filter_already_published_packages(packages, debian_repository)
 
+    if only_names is not None:
+        packages = [p for p in packages if p.blueprint.name in only_names]
+
     # run fetch instructions (download, verify, extract) in parallel
     files = [p.remote_file for p in packages if p.remote_file is not None]
     fetch_results, fetch_errors = fetch_remote_files(files)
